@@ -1,13 +1,14 @@
-"""Miscellaneous functions
+"""Miscellaneous functions.
 
 run_command borrowed from Cheesecake - See CREDITS.
 
 """
 
 import os
+import shlex
 import signal
+import subprocess
 import time
-from subprocess import Popen, STDOUT
 
 
 def get_yolk_dir():
@@ -16,12 +17,23 @@ def get_yolk_dir():
 
 
 def run_command(cmd, env=None, max_timeout=None):
-    """Run command and return its return status code and its output."""
-    arglist = cmd.split()
+    r"""Run command and return its return status code and its output.
 
-    output = os.tmpfile()
+    >>> run_command('true')
+    (0, '')
+
+    >>> run_command('false')
+    (1, '')
+
+    >>> run_command('echo hello world')
+    (0, 'hello world\n')
+
+    """
     try:
-        pipe = Popen(arglist, stdout=output, stderr=STDOUT, env=env)
+        pipe = subprocess.Popen(shlex.split(cmd),
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.STDOUT,
+                                env=env)
     except Exception as errmsg:
         return 1, errmsg
 
@@ -36,11 +48,10 @@ def run_command(cmd, env=None, max_timeout=None):
                 return 1, 'Time exceeded'
 
     pipe.wait()
-    output.seek(0)
-    return pipe.returncode, output.read()
+    return pipe.returncode, pipe.communicate()[0].decode('utf-8')
 
 
 def command_successful(cmd):
     """Returns True if command exited normally, False otherwise."""
-    return_code, _output = run_command(cmd)
+    return_code, _ = run_command(cmd)
     return return_code == 0
